@@ -8,9 +8,9 @@ from .errors import tb_str, SimulationError
 from .system import NumerousSystem
 
 from .report.report import Report
-from numerous_api_client.client.data_source import DataSourceHibernating, DataSourceEmptyDataset, \
-    DataSourceStreamClosed, DataSourceCompleted
-from numerous_api_client.client.numerous_client import ScenarioStatus
+from numerous.client.data_source import DataSourceHibernating, DataSourceEmptyDataset, \
+    DataSourceStreamClosed, DataSourceCompleted, DataSourceStreamStarting
+from numerous.client import ScenarioStatus
 
 LOG_LEVEL = os.getenv('LOG_LEVEL', logging.DEBUG)
 
@@ -222,6 +222,11 @@ class NumerousSimulationJob(NumerousBaseJob):
                     exit_code = ExitCode.SOURCE_CLOSED
                     details = tb_str(e)
                     break
+                except DataSourceStreamStarting:
+                    self.app.nc.set_scenario_progress('waiting for input stream to start',
+                                                      ScenarioStatus.INITIALZING, 0.0)
+                    sleep(0.1)
+                    continue
 
                 completed = 0
                 if t_stop > 0:
