@@ -1,12 +1,15 @@
 import copy
-
-from numerous_api_client.client.numerous_client import ScenarioStatus, NumerousClient
 import os
 import sys
 import logging
 import importlib
+
 from pathlib import Path
+from time import sleep
+
 from numerous_image_tools.errors import tb_str
+from numerous.client import ScenarioStatus, NumerousClient
+from numerous.client.data_source import DataSourceStreamStarting
 
 logger = logging.getLogger('sim-setup')
 
@@ -74,6 +77,7 @@ class NumerousSystem:
         self._initialized = False
         self.logger = logging.getLogger('NumerousSystem')
         self._model_folder = model_folder
+        self._has_model = False
 
         # Update status - clear current data
         self.nc.set_scenario_progress('Environment Initializing',ScenarioStatus.ENVIRONMENT_INITIALIZING, 0.0, clean=True)
@@ -96,13 +100,25 @@ class NumerousSystem:
 
         self.input = input
 
-        try:
-            data = self.input.get_at_time(t)
-            self.update_inputs(data)
-            self.initialize_model()
-        except Exception as e:
+        if self._has_model:
+            while True:
+                try:
+                    data = self.input.get_at_time(t)
+                    self.update_inputs(data)
+                    self.initialize_model()
+                    self.nc.set_scenario_progress('model initialized', ScenarioStatus.INITIALZING, 0.0)
+                    self._initialized = True
+                    break
 
-            self.logger.error(f"could not initialize model {tb_str(e)}")
+                except DataSourceStreamStarting:
+                    self.nc.set_scenario_progress('waiting for input stream to start', ScenarioStatus.INITIALZING, 0.0)
+                    sleep(0.1)
+                    continue
+                except Exception as e:
+                    self.logger.error(f"could not initialize model {tb_str(e)}")
+                    break
+        else:
+            self._initialized = True
 
         self.logger.debug("completed setup")
 
@@ -124,8 +140,6 @@ class NumerousSystem:
         for component in self.components.values():
             component.model = component._initialize(self)
 
-        self._initialized = True
-
     def _dynamic_import_components(self):
         for component in self.components.values():
             self._add_path_topdown(component._folder)
@@ -160,6 +174,8 @@ class NumerousSystem:
             component = self._add_components_recursive(simcomponents, simcomponent)
             components.update({simcomponent['name']: component})
             component_list.append(component)
+            if component._import:
+                self._has_model = True
 
         # Return list of components
 
